package com.muyu.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.csp.sentinel.Entry;
import com.alibaba.csp.sentinel.SphU;
import com.alibaba.csp.sentinel.slots.block.BlockException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.system.domain.BookInfo;
import com.muyu.system.service.IBookInfoService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 书籍Controller
 *
 * @author muyu
 * @date 2024-02-23
 */
@RestController
@RequestMapping("/info")
public class BookInfoController extends BaseController
{
    @Autowired
    private IBookInfoService bookInfoService;

    /**
     * 查询列表
     */
    @RequiresPermissions("system:info:list")
    @GetMapping("/list")
    public Result<TableDataInfo<BookInfo>> list(BookInfo bookInfo)
    {
            startPage();
            List<BookInfo> list = bookInfoService.selectBookInfoList(bookInfo);
            return getDataTable(list);
    }

    /**
     * 导出导出列表
     */
    @RequiresPermissions("system:info:export")
    @Log(title = "导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BookInfo bookInfo)
    {
        List<BookInfo> list = bookInfoService.selectBookInfoList(bookInfo);
        ExcelUtil<BookInfo> util = new ExcelUtil<BookInfo>(BookInfo.class);
        util.exportExcel(response, list, "bookInfo数据");
    }

    /**
     * 获取书籍详细信息
     */
    @RequiresPermissions("system:info:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(bookInfoService.selectBookInfoById(id));
    }

    /**
     * 新增bookInfo
     */
    @RequiresPermissions("system:info:add")
    @Log(title = "书籍添加", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody BookInfo bookInfo)
    {
        return toAjax(bookInfoService.insertBookInfo(bookInfo));
    }

    /**
     * 修改
     */
    @RequiresPermissions("system:info:edit")
    @Log(title = "书记修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody BookInfo bookInfo)
    {
        return toAjax(bookInfoService.updateBookInfo(bookInfo));
    }

    /**
     * 删除
     */
    @RequiresPermissions("system:info:remove")
    @Log(title = "书记修改", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(bookInfoService.deleteBookInfoByIds(ids));
    }
}
