package com.muyu.system.service.impl;

import com.alibaba.csp.sentinel.EntryType;
import com.alibaba.csp.sentinel.annotation.SentinelResource;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.system.domain.BookInfo;
import com.muyu.system.mapper.BookInfoMapper;
import com.muyu.system.service.IBookInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * bookInfoService业务层处理
 *
 * @author muyu
 * @date 2024-02-23
 */
@Service
public class BookInfoServiceImpl implements IBookInfoService {
    @Autowired
    private BookInfoMapper bookInfoMapper;


    /**
     * 查询bookInfo
     *
     * @param id bookInfo主键
     * @return bookInfo
     */
    @Override
    public BookInfo selectBookInfoById(Long id) {
        return bookInfoMapper.selectBookInfoById(id);
    }

    /**
     * 查询bookInfo列表
     *
     * @param bookInfo bookInfo
     * @return bookInfo
     */
    @Override
    @SentinelResource(value = "selectBookInfoList", entryType = EntryType.IN)
    public List<BookInfo> selectBookInfoList(BookInfo bookInfo) {
        bookInfo.setCreateBy(SecurityUtils.getUsername());
        return bookInfoMapper.selectBookInfoList(bookInfo);
    }

    /**
     * 新增bookInfo
     *
     * @param bookInfo bookInfo
     * @return 结果
     */
    @Override
    public int insertBookInfo(BookInfo bookInfo) {
        bookInfo.setCreateTime(DateUtils.getNowDate());
        bookInfo.setCreateBy(SecurityUtils.getUsername());
        return bookInfoMapper.insertBookInfo(bookInfo);
    }

    /**
     * 修改bookInfo
     *
     * @param bookInfo bookInfo
     * @return 结果
     */
    @Override
    public int updateBookInfo(BookInfo bookInfo) {
        bookInfo.setUpdateTime(DateUtils.getNowDate());
        bookInfo.setCreateBy(SecurityUtils.getUsername());
        return bookInfoMapper.updateBookInfo(bookInfo);
    }

    /**
     * 批量删除bookInfo
     *
     * @param ids 需要删除的bookInfo主键
     * @return 结果
     */
    @Override
    public int deleteBookInfoByIds(Long[] ids) {
        return bookInfoMapper.deleteBookInfoByIds(ids);
    }

    /**
     * 删除bookInfo信息
     *
     * @param id bookInfo主键
     * @return 结果
     */
    @Override
    public int deleteBookInfoById(Long id) {
        return bookInfoMapper.deleteBookInfoById(id);
    }
}
